/*****************************************************************************
 Copyright  Newcastle University
 Author      Paul Coates
 *****************************************************************************/
#include <stdio.h>
#include "index.h"
#include "misc.h"

void swap(Index &a, Index &b)
{
	Index c = a;
	a = b;
	b = c;
}

void quicksort(Index idx[], int low, int high)
{
	Index pivot;
	int scanup, scandown;
	int mid;

	if (high - low <= 0)	return;
	else
	if (high - low == 1)
	{
		if (idx[high] < idx[low])
			swap(idx[high], idx[low]);
		return;
	}

	mid = (low + high)/2;
	pivot = idx[mid];

	swap(idx[mid], idx[low]);
	scanup = low+1;
	scandown = high;

	do
	{
		while ((scanup <= scandown) && (idx[scanup] <= pivot)) scanup++;
		while (pivot < idx[scandown]) scandown--;
		if (scanup < scandown) swap(idx[scanup], idx[scandown]);
	}while(scanup<scandown);

	idx[low] = idx[scandown];
	idx[scandown] = pivot;

	if (low < scandown-1) quicksort(idx, low, scandown-1);
	if (scandown+1 < high) quicksort(idx, scandown+1, high);
}

int operator < (Index &l, Index &r)
{
	if (l.type == 1)
	{
		return (strcmp(l.str_val, r.str_val)<0);
	}else
	if (l.type == 3)
	{
		return (compare_ip_addresses(l.str_val, r.str_val)==-1);
	}else
		return (l.int_val < r.int_val);
}

int operator <= (Index &l, Index &r)
{
	if (l.type == 1)
	{
		return (strcmp(l.str_val, r.str_val)<=0);
	}else
	if (l.type == 3)
	{
		return (compare_ip_addresses(l.str_val, r.str_val)!=1);
	}else
		return (l.int_val <= r.int_val);
}

Index::Index()
{
	type = 0;
	offset = 0;
	int_val = 0;
	strcpy(str_val, "");
	ptr = NULL;
}

Index::~Index()
{
}

Index::Index(Index &orig)
{
	type = orig.type;
	offset = orig.offset;
	int_val = orig.int_val;
	strcpy(str_val, orig.str_val);
	ptr = orig.ptr;
}

void Index::operator = (const Index &orig)
{
	type = orig.type;
	offset = orig.offset;
	int_val = orig.int_val;
	strcpy(str_val, orig.str_val);
	ptr = orig.ptr;
}

