/*****************************************************************************
 Copyright  Newcastle University
 Author      Paul Coates
 *****************************************************************************/
#include "ipaddress.h"
#include "interface.h"
#include "network.h"
#include "misc.h"

Interface::Interface()
{
	clear();
}

Interface::~Interface()
{
}

void Interface::clear()
{
	int i;

	index = 0;
	for (i=0; i<6; i++) mac[i] = 0;
	speed = 0;
	type = 0;
	status = 0;
	strcpy(descr, "");
	strcpy(port, "");
	network = NULL;
	router = NULL;
}

void Interface::print()
{
	printf("  Index %d, mac ", index);
	print_mac(mac);
	printf(", speed %lu, type %d, status %d, descr \"%s\"\n",
		speed, type, status, descr);
}

void Interface::save(FILE *f)
{
	int i;
	IPAddress *tmpip;
	Link *ln;

	write_int(f, index);
	for (i=0; i<6; i++)  fputc(mac[i], f);
	write_ulong(f, speed);
	write_int(f, type);
	write_int(f, status);
	for (i=0; i<64; i++)  fputc(descr[i], f);
	for (i=0; i<64; i++)  fputc(port[i], f);
	write_int(f, ip_addresses.size());
	for (ln=ip_addresses.get_head(); ln!=NULL; ln=ln->next)
	{
		tmpip = (IPAddress*) ln->item;
		tmpip->save(f);
	}
}

void Interface::load(FILE *f)
{
	int i, j;
	IPAddress *tmpip;

	index = read_int(f);
	for (i=0; i<6; i++)  mac[i] = fgetc(f);
	speed = read_ulong(f);
	type = read_int(f);
	status = read_int(f);
	for (i=0; i<64; i++) descr[i] = fgetc(f); descr[64] = '\0';
	for (i=0; i<64; i++) port[i] = fgetc(f); port[64] = '\0';
	j = read_int(f);
	for (i=0; i<j; i++)
	{
		tmpip = new IPAddress();
		tmpip->load(f);
		ip_addresses.add(tmpip);
	}
}

