/*****************************************************************************
 Copyright  Newcastle University
 Author      Paul Coates
 *****************************************************************************/
#include <stdlib.h>
#include "machine.h"
#include "network.h"
#include "subnet.h"
#include "misc.h"

Machine::Machine()
{
	clear();
}

Machine::~Machine()
{
}

void Machine::clear()
{
	int i;

	strcpy(name, "");
	ip.clear();
	last_seen = 0;
	strcpy(location, "");
	strcpy(descr, "");
	strcpy(contact, "");
	for (i=0; i<6; i++) mac[i] = 0;
	registered = 0;
	place = 0;
	find = 0;
	network = NULL;
}

void Machine::print()
{
	int i, j;

	printf("name \"%s\", ip ", name);
	ip.print();
	printf(", mac ");
	print_mac(mac);
	printf(", location %s, descr %s, contact %s, registered %d, lastseen ", location, descr, contact, registered);
}

void Machine::save(FILE *f)
{
	int i, j;

	for (i=0; i<64; i++) fputc(name[i], f);
	ip.save(f);
	write_time_t(f, last_seen);
	for (i=0; i<64; i++) fputc(location[i], f);
	for (i=0; i<64; i++) fputc(descr[i], f);
	for (i=0; i<64; i++) fputc(contact[i], f);
	for (i=0; i<6; i++)  fputc(mac[i], f);
	write_int(f, registered);
	write_int(f, place);
}

void Machine::load(FILE *f)
{
	int i, j;

	for (i=0; i<64; i++) name[i] = fgetc(f); name[64] = '\0';
	ip.load(f);
	last_seen = read_time_t(f);
	for (i=0; i<64; i++) location[i] = fgetc(f); location[64] = '\0';
	for (i=0; i<64; i++) descr[i] = fgetc(f); descr[64] = '\0';
	for (i=0; i<64; i++) contact[i] = fgetc(f); contact[64] = '\0';
	for (i=0; i<6; i++)  mac[i] = fgetc(f);
	registered = read_int(f);
	place = read_int(f);
}

void Machine::match(char *string)
{
	char mac2[16];
	char ip2[16];

	find = 0;

	if (strlen(string)==0) return;

	ip.sprint(ip2);
	sprint_mac(mac, mac2);
	if ((contains(name, string)) ||
			(contains(mac2, string)) ||
			(contains(location, string)) ||
			(contains(descr, string)) ||
			(contains(contact, string)) ||
			(contains(ip2, string)))
		find = 1;
}

