/*****************************************************************************
 Copyright  Newcastle University
 Author      Paul Coates
 *****************************************************************************/
#include <stdlib.h>
#include "router.h"
#include "ipaddress.h"
#include "interface.h"
#include "misc.h"

Router::Router()
{
	clear();
}

Router::~Router()
{
	Interface *in;
	Link *ln;

	for (ln=interfaces.get_head(); ln!=NULL; ln=ln->next)
	{
		in = (Interface*) ln->item;
		delete in;
	}
}

void Router::clear()
{
	int i;

	x = rand()%400;
	y = rand()%300;
	w = h = 16;
	selected = 0;
	show = 1;
	type = 'u';
	visited = 0;
	find = 0;

	strcpy(name, "");
	last_seen = 0;
	strcpy(community, "");
	strcpy(location, "");
	strcpy(descr, "");
	strcpy(contact, "");
	status = 0;
	registered = 0;
	matrix = 0;
}

void Router::print()
{
	int i, j;
	Interface *in;

	j = interfaces.size();
	printf("name \"%s\", ", name);
	printf("type %c, num_interfaces %d\n", type, j);
	for (i=0; i<j; i++)
	{
		in = (Interface*) interfaces.get_item(i);
		in->print();
	}
}

void Router::save(FILE *f)
{
	int i, j;
	Interface *in;
	Link *ln;

	pingname.save(f);
	for (i=0; i<64; i++) fputc(name[i], f);
	write_time_t(f, last_seen);
	for (i=0; i<64; i++) fputc(location[i], f);
	for (i=0; i<64; i++) fputc(descr[i], f);
	for (i=0; i<64; i++) fputc(contact[i], f);
	for (i=0; i<64; i++) fputc(community[i], f);
	write_int(f, registered);
	write_int(f, matrix);
	fputc(type, f);
	write_int(f, interfaces.size());
	for (ln=interfaces.get_head(); ln!=NULL; ln=ln->next)
	{
		in = (Interface*) ln->item;
		in->save(f);
	}
}

void Router::load(FILE *f)
{
	int i, j;
	Interface *in;

	pingname.load(f);
	for (i=0; i<64; i++) name[i] = fgetc(f); name[64] = '\0';
	last_seen = read_time_t(f);
	for (i=0; i<64; i++) location[i] = fgetc(f); location[64] = '\0';
	for (i=0; i<64; i++) descr[i] = fgetc(f); descr[64] = '\0';
	for (i=0; i<64; i++) contact[i] = fgetc(f); contact[64] = '\0';
	for (i=0; i<64; i++) community[i] = fgetc(f); community[64] = '\0';
	registered = read_int(f);
	matrix = read_int(f);
	type = fgetc(f);
	j = read_int(f);
	interfaces.clear();
	for (i=0; i<j; i++)
	{
		in = new Interface();
		in->load(f);
		in->router = this;
		interfaces.add(in);
	}
}

void Router::match(char *string)
{
	char mac[16];
	char ip3[16];
	Interface *in;
	Link *ln, *ln2;
	IPAddress *ip2;

	find = 0;
	if (strlen(string)==0) return;

	if ((strlen(name)>0) && (lower_contains(name, string))) find = 1; else
	if ((strlen(location)>0) && (lower_contains(location, string))) find = 2; else
	if ((strlen(descr)>0) && (lower_contains(descr, string))) find = 3; else
	if ((strlen(contact)>0) && (lower_contains(contact, string))) find = 4;

	for (ln = interfaces.get_head(); ln!=NULL; ln=ln->next)
	{
		in = (Interface*) ln->item;
		sprint_mac(in->mac, mac);
		if ((strlen(mac)>0) && (lower_contains(mac, string))) find = 5;
		for (ln2 = in->ip_addresses.get_head(); ln2!=NULL; ln2=ln2->next)
		{
			ip2 = (IPAddress*) ln2->item;
			ip2->sprint(ip3);
			if (contains(ip3, string)) find = 6;
		}
	}
}

